/*
 * Author: Richard Lord
 * Copyright (c) Richard Lord 2010
 * http://www.richardlord.net
 * 
 * Licence Agreement
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package net.richardlord.smartcomponents.twitter.context
{
	import flash.display.DisplayObjectContainer;
	import flash.events.Event;
	import flash.utils.getQualifiedClassName;
	
	import mx.core.IMXMLObject;
	
	import net.expantra.smartypants.Injector;
	import net.expantra.smartypants.SmartyPants;
	import net.richardlord.smartcomponents.twitter.data.TweetCollection;
	import net.richardlord.smartcomponents.twitter.data.User;
	import net.richardlord.smartcomponents.twitter.managers.AuthenticateManager;
	import net.richardlord.smartcomponents.twitter.signals.SignalBus;
	
	import org.flaircode.oauth.IOAuth;
	import org.flaircode.oauth.OAuth;
	
	public class TwitterContext implements IMXMLObject
	{
		private var injector : Injector;
		
		private var container : DisplayObjectContainer;
		
		private var packages : Array;
		
		private const defaultPackage : String = "net.richardlord.smartcomponents.twitter";
		
		[Inspectable( defaultValue="", category="Common" )]
		public var oauthConsumerKey : String;
		
		[Inspectable( defaultValue="", category="Common" )]
		public var oauthConsumerSecret : String;
		
		public function TwitterContext()
		{
			SmartyPants.singleInjectorMode = false;
		}
		
		public function initialized( document : Object, id : String ) : void
		{
			packages = new Array( defaultPackage );
			createContext();
			listenOnDisplayList( document );
		}
		
		[ArrayElementType( "String" )]
		[Inspectable( arrayType="String" )]
		public function set customPackages( value : Array ) : void
		{
			packages = [ defaultPackage ].concat( value );
		}
		
		private function createContext() : void
		{
			injector = SmartyPants.getOrCreateInjectorFor( this );
			
			injector.newRule().whenAskedFor( SignalBus ).useSingleton();
			injector.newRule().whenAskedFor( TweetCollection ).useSingleton();
			injector.newRule().whenAskedFor( User ).useSingleton();
			injector.newRule().whenAskedFor( AuthenticateManager ).useSingleton();
			injector.newRule().whenAskedFor( IOAuth ).useValue( new OAuth( oauthConsumerKey, oauthConsumerSecret ) );
		}
		
		private function listenOnDisplayList( document : Object ) : void
		{
			if ( document is DisplayObjectContainer )
			{
				container = document as DisplayObjectContainer;
				container.addEventListener( Event.ADDED_TO_STAGE, injectDisplayObject, true, 0, true );
			}
		}
		
		private function injectDisplayObject( event : Event ) : void
		{
			var displayObject : * = event.target;
			var name : String = getQualifiedClassName( displayObject );
			for each ( var pkg : String in packages )
			{
				if ( name.substring( 0, pkg.length ) == pkg )
				{
					injector.injectInto( displayObject );
					break;
				}
			}
		}
	}
}