/*
 * Author: Richard Lord
 * Copyright (c) Richard Lord 2010
 * http://www.richardlord.net
 * 
 * Licence Agreement
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package net.richardlord.smartcomponents.twitter.managers
{
	import mx.controls.Alert;
	
	import net.expantra.smartypants.Injector;
	import net.richardlord.smartcomponents.twitter.data.TweetCollection;
	import net.richardlord.smartcomponents.twitter.services.SearchService;
	import net.richardlord.smartcomponents.twitter.signals.SignalBus;
	
	public class SearchManager
	{
		[Inject]
		public var service : SearchService;
		
		[Inject]
		public var tweetCollection : TweetCollection;
		
		[Inject]
		public var signalBus : SignalBus;
		
		[PostConstruct]
		public function setUpListeners( injector : Injector ) : void
		{
			service.serviceCompleteSignal.add( updateTweetCollection );
			service.serviceFailedSignal.add( sendFailureAlert );
		}
		
		public function search( searchTerm : String, resultsCount : uint ) : void
		{
			service.send( searchTerm, resultsCount );
		}
		
		private function updateTweetCollection( tweets : TweetCollection ) : void
		{
			tweetCollection.assign( tweets );
			signalBus.tweetsLoaded.dispatch();
			signalBus.hideSearch.dispatch();
		}
		
		private function sendFailureAlert() : void
		{
			Alert.show( "Failed to load tweets" );
		}
	}
}