/*
 * Author: Richard Lord
 * Copyright (c) Richard Lord 2010
 * http://www.richardlord.net
 * 
 * Licence Agreement
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package net.richardlord.smartcomponents.twitter.services
{
	import flash.net.URLRequestMethod;
	import flash.net.URLVariables;
	
	import net.expantra.smartypants.Injector;
	import net.richardlord.smartcomponents.twitter.data.Tweet;
	import net.richardlord.smartcomponents.twitter.services.parsers.TweetXmlParser;
	import net.richardlord.smartcomponents.twitter.services.tools.TwitterRequest;
	
	import org.osflash.signals.Signal;
	
	public class TweetService
	{
		private static const SERVICE_URL : String = "http://api.twitter.com/1/statuses/update.xml";
		
		[Inject]
		public var request : TwitterRequest;
		
		[Inject]
		public var parser : TweetXmlParser;
		
		public var serviceCompleteSignal : Signal;
		public var serviceFailedSignal : Signal;
		
		[PostConstruct]
		public function setUpListeners( injector : Injector ) : void
		{
			serviceCompleteSignal = new Signal( Tweet );
			serviceFailedSignal = new Signal();
			request.requestCompleteSignal.add( parseResults );
			request.requestFailedSignal.add( signalFailure );
		}
		
		public function send( status : String ) : void
		{
			request.loadDataFormat = TwitterRequest.FORMAT_XML;
			request.sendMethod = URLRequestMethod.POST;
			request.url = SERVICE_URL;
			
			var data : URLVariables = new URLVariables();
			data.status = status;
			request.sendData = data;
			
			request.sendAndLoad();
		}
		
		private function parseResults( xml : XML ) : void
		{
			var tweet : Tweet = parser.parseTweet( xml );
			serviceCompleteSignal.dispatch( tweet );
		}
		
		private function signalFailure() : void
		{
			serviceFailedSignal.dispatch();
		}
	}
}